@@ -71,6 +71,16 @@ class LoginRequest(DSRequest):
                                     status__name=status_operation_types.name,
                                 ))
 
+                        from kaf_pas.ckk.models.locations_users import Locations_users
+                        from kaf_pas.ckk.models.locations_view import Locations_view
+                        if user.is_admin or user.is_develop:
+                            workshops=[]
+                        else:
+                            workshops = [Locations_view.objects.get(id=Locations_users.location.id).workshop for Locations_users in Locations_users.objects.filter(user=user)]
+                            workshops = [workshop.id if workshop else 0 for workshop in workshops]
+                            if len(workshops) == None:
+                                workshops = [-1]
+
                         self.response = dict(
                             captionUser=user.get_short_name,
                             chatInfo=LoginRequest.get_chats(user),
@@ -97,6 +107,7 @@ class LoginRequest(DSRequest):
                             user__color=user.color if user.color != None and user.color != 'undefined' else 'black',
                             user_full_name=user.get_full_name,
                             user_short_name=user.get_short_name,
+                            workshops=workshops,
                             userId=user.id,
                             ws_channel=ws_channel,
                             ws_host=settings.WS_HOST,
@@ -131,7 +142,7 @@ class LoginRequest(DSRequest):
         tetatet_chats_sender = []
         tetatet_chats = []
 
-        key='LoginRequest.get_chats'
+        key = 'LoginRequest.get_chats'
         settings.LOCKS.acquire(key)
         for chat in Chat_user_user.objects.filter(user_reciver=user):
             tetatet_chats_reciver.append(dict(
@@ -207,7 +218,7 @@ class LoginRequest(DSRequest):
         _user = user
         _bot = bot
 
-        key='LoginRequest.send_bot_message'
+        key = 'LoginRequest.send_bot_message'
         settings.LOCKS.acquire(key)
         if not isinstance(_user, User) and isinstance(_user, int):
             _user = User.objects.get(id=_user)
