@@ -1,3 +1,6 @@
+import datetime
+
+
 def IsBitOn(value, bit):
     res = (value & (1 << bit))
     if isinstance(res, int):
@@ -5,6 +8,10 @@ def IsBitOn(value, bit):
     return (value & (1 << bit))._value != 0
 
 
+def IsBitOff(value, bit):
+    return not IsBitOn(value, bit)
+
+
 def TurnBitOn(value, bit):
     return value | (1 << bit)
 
@@ -18,3 +25,5 @@ def CopyBit(value, bit):
         return TurnBitOn(value, bit)
     else:
         return TurnBitOff(value, bit)
+
+
