@@ -6,6 +6,8 @@ import traceback
 import websocket
 from django.conf import settings
 
+from isc_common import setAttr
+
 
 class WebSocket:
     procedures = []
@@ -38,12 +40,13 @@ class WebSocket:
         if not isinstance(message, dict):
             raise Exception(f'message is not dict instance')
 
-        settings.LOCKS.acquire('WebSocket.recv')
+        key = 'WebSocket.recv'
+        settings.LOCKS.acquire(key)
         try:
             url = f'ws://{host}:{port}/ws/{channel}/'
             ws = websocket.create_connection(url)
             ws.send(json.dumps(message))
-            settings.LOCKS.release('WebSocket.recv')
+            settings.LOCKS.release(key)
             return ws, json.loads(ws.recv())
         except Exception as ex:
 
@@ -57,7 +60,7 @@ class WebSocket:
                 logger.error(x)
 
             del exc_info
-            settings.LOCKS.release('WebSocket.recv')
+            settings.LOCKS.release(key)
             return None
 
     @staticmethod
@@ -80,19 +83,18 @@ class WebSocket:
             raise Exception(f'channel is not exists.')
 
         message = kwrags.get('message')
-        if not message:
-            raise Exception(f'message is not exists.')
 
         if not isinstance(message, dict):
             raise Exception(f'message is not dict instance')
 
         try:
-            settings.LOCKS.acquire('WebSocket.send_message')
+            key = 'WebSocket.send_message'
+            settings.LOCKS.acquire(key)
             url = f'ws://{host}:{port}/ws/{channel}/'
             ws = websocket.create_connection(url)
             ws.send(json.dumps(message))
             ws.close()
-            settings.LOCKS.release('WebSocket.send_message')
+            settings.LOCKS.release(key)
         except Exception as ex:
 
             exc_info = sys.exc_info()
@@ -105,47 +107,79 @@ class WebSocket:
                 logger.error(x)
 
             del exc_info
-            settings.LOCKS.release('WebSocket.send_message')
+            settings.LOCKS.release(key)
 
-    def on_message(self, message):
-        for proc in self.procedures:
-            if hasattr(proc, '__call__'):
-                proc(message)
+    @staticmethod
+    def send_warning_message(**kwrags):
+        setAttr(kwrags, 'type', 'warn')
+        WebSocket.send_typing_message(**kwrags)
 
-    def on_error(self, error):
-        self.logger.error(error)
+    @staticmethod
+    def send_typing_message(**kwrags):
 
-    def on_close(self):
-        self.logger.debug(f'### closed ###')
+        type = kwrags.get('type')
+        if not type:
+            raise Exception(f'channel is not type.')
 
-    def on_open(self):
-        self.logger.debug(f'### opened ###')
+        message = kwrags.get('message')
+        if isinstance(message, str):
+            message = dict(
+                message=message,
+                type=type,
+            )
 
-    def remove_proc(self, proc):
-        self.procedures.remove(proc)
+        setAttr(kwrags, 'message', message)
 
-    def append_proc(self, proc):
-        self.procedures.append(proc)
+        WebSocket.send_message(**kwrags)
 
-    def send(self, data):
-        if isinstance(data, dict):
-            self.webSocket.send(json.dumps(data))
-        else:
-            raise Exception(f'data is not dict.')
 
-    def send_logging(self, msg, type='logging'):
-        data = dict(msg=msg, type=type)
-        # self.webSocket.send(json.dumps(data))
+def on_message(self, message):
+    for proc in self.procedures:
+        if hasattr(proc, '__call__'):
+            proc(message)
 
-    def __init__(self, **kwargs):
-        for k, v in kwargs.items():
-            setattr(self, k, v() if callable(v) else v)
 
-        websocket.enableTrace(True)
-        self.webSocket = websocket.WebSocketApp(f'ws://{self.host}:{self.port}/ws/{self.channel}/',
-                                                on_message=self.on_message,
-                                                on_error=self.on_error,
-                                                on_close=self.on_close,
-                                                on_open=self.on_open
-                                                )
-        self.webSocket.run_forever()
+def on_error(self, error):
+    self.logger.error(error)
+
+
+def on_close(self):
+    self.logger.debug(f'### closed ###')
+
+
+def on_open(self):
+    self.logger.debug(f'### opened ###')
+
+
+def remove_proc(self, proc):
+    self.procedures.remove(proc)
+
+
+def append_proc(self, proc):
+    self.procedures.append(proc)
+
+
+def send(self, data):
+    if isinstance(data, dict):
+        self.webSocket.send(json.dumps(data))
+    else:
+        raise Exception(f'data is not dict.')
+
+
+def send_logging(self, msg, type='logging'):
+    data = dict(msg=msg, type=type)
+    # self.webSocket.send(json.dumps(data))
+
+
+def __init__(self, **kwargs):
+    for k, v in kwargs.items():
+        setattr(self, k, v() if callable(v) else v)
+
+    websocket.enableTrace(True)
+    self.webSocket = websocket.WebSocketApp(f'ws://{self.host}:{self.port}/ws/{self.channel}/',
+                                            on_message=self.on_message,
+                                            on_error=self.on_error,
+                                            on_close=self.on_close,
+                                            on_open=self.on_open
+                                            )
+    self.webSocket.run_forever()
