@@ -58,9 +58,10 @@ class MessagesManager(CommonTreeGridManager):
 
     @staticmethod
     def get_tracker_bot():
-        settings.LOCKS.acquire('MessagesManager.get_tracker_bot')
+        key='MessagesManager.get_tracker_bot'
+        settings.LOCKS.acquire(key)
         tracker_bot, _ = User.objects.get_or_create(username='tracker_bot', last_name='Бот (Дела)', password='1234567890', props=User.props.bot, deliting=False, editing=False)
-        settings.LOCKS.release('MessagesManager.get_tracker_bot')
+        settings.LOCKS.release(key)
         return tracker_bot
 
     @staticmethod
